# MRT

Multi Reclass Tool (MRT)

Code door: Hans Roelofsen (WEnR team Biodiversiteit & Beleid)

Idee en eerste prototype: Henk Meeuwsen (WEnR team Biodiversiteit & Beleid)

oktober 2020

### inleiding
Bij WEnR worden ecologische modellen ontwikkeld en toegepast. Hiervoor zijn vaak diverse kaartlagen vereist als input, zoals bijv. Top10 en de Bij12 [Beheertypenkaart](https://www.bij12.nl/onderwerpen/natuur-en-landschap/index-natuur-en-landschap/natuurtypen/). Regelmatig blijkt dat sommige kaartlagen onvoldoende detail bevatten. Vaak kan dit worden opgelost door twee of meer kaartlagen met elkaar te combineren en bepaalde combinaties van waarden in de verschillende lagen te hernoemen tot een nieuwe waarde en aan de hand daarvan een afgeleide kaart te genereren. Hiervoor is de MRT ontwikkeld. 

### installatie & voorbereiding
  1. installeer [git](https://git-scm.com/) 
  2. installeer [miniconda](https://docs.conda.io/en/latest/miniconda.html)
  3. clone deze repository naar een lokale directory (bijv `c:/apps/mrt`) mbv git: `git clone  git@git.wur.nl:roelo008/mrt.git`
  4. mbv miniconda creeer de vereiste Python environment volgens de specificaties van  `environment.yml`: `conda env create -f environment.yml`. Zie ook [hier](https://docs.conda.io/projects/conda/en/latest/user-guide/tasks/manage-environments.html#creating-an-environment-from-an-environment-yml-file).
  5. activeer de Python environment: `activate mrt_env`. Zie ook [hier](https://docs.conda.io/projects/conda/en/latest/user-guide/tasks/manage-environments.html#activating-an-environment).
  6. verifieer dat MRT werk: `python c:/apps/mrt/sample/MRT.py -h`

### input data 
##### gecombineerd raster
MRT werkt met een 'gecombineerd' raster zoals dat gemaakt is door de [ArcGIS Pro Combine Tool](https://pro.arcgis.com/en/pro-app/tool-reference/spatial-analyst/combine.htm). Het gecombineerde raster  heeft een integer getal toegekend aan elke unieke combinatie van getallen in de bron-rasters. Elk bron-raster staat geregistreerd als een aparte kolom in de Raster Attribute Table (RAT) van het gecombineerde raster. De getallen in de bron-rasters representeren verschillende landgebruik categorieën. 

##### beslisregels
In een Excel sheet met wordt met beslisregels per combinatie van waardes in de verschillende bron-rasters aangegeven welke nieuwe waarde deze combinatie moet krijgen in de afgeleide kaart. De MRT past de beslisregels hiërarchisch toe op het gecombineerde raster en creëert een nieuw raster waarbij elke integer-waarde een bepaalde beslisregel (maw een nieuwe landgebruikscategorie) vertegenwoordigt. De hiërarchie houdt in dat wanneer aan een bepaalde cel eenmaal een waarde is toegekend aan de hand van een beslisregel, die waarde niet meer wordt overschreven door een latere beslisregel die eveneens op de cel van toepassing is. Een beslisregel bevat de volgende informatie:

  1. het getal dat de nieuwe landgebruikscategorie vertegenwoordigt `newval`
  2. een omschrijving van de nieuwe categorie `description`
  3. welke waardes uit elk bron-raster *wel* meedoen (hele getallen, komma gescheiden)
  4. welke waardes uit elk bron-raster *niet* meedoen (hele getallen met prefix `-`)
  5. indifferentie naar een bron-raster wordt aangeduid met `n`

In onderstaand voorbeeld combineren de eerste twee beslisregels  beheertype [N16.03](https://www.bij12.nl/onderwerpen/natuur-en-landschap/index-natuur-en-landschap/natuurtypen/n16-bossen-met-productiefunctie/n16-03-droog-bos-productie-nieuw-per-01-01-2018/) met Top10 categorieën 142 (gemend bos) en 143 (loofbos) tot twee nieuwe categorieën: 'Gemengd droog bos met productie' (newval 10) en 11: 'Droog loofbos met productie' (newval 11). De volgende beslisregel combineert gebouwen uit Top10 met de kaartlaag van bedrijventerreinen om 'gebouw op berijventerrein' te maken. De laatste regel omvat alle gebouwen voor zover die niet aan eerdere regels zijn toegekend. `n` betekent dat de kaartlaag niet relevant is in de beslisregel.

| newval | description | Top10 | Beheertypen | bedrijventerrein |
| ------ | ------ | ------ |------ | ----- |
| 10 | Gemengd droog bos met productie | 142 | 1603 | n |
| 11 | Droog Loofbos met productie | 143 | 1603 | n |
| 12 | Gebouw op bedrijventerrein | 90 | n | 1 |
| 13 | Gebouw | 90 | n | n| 

##### downstream
De nieuwe landgebruik categorieën kunnen optioneel door-vertaald worden naar een andere categorisatie. Dit noemen we 'downstream'. Hiermee kan de kaart bijv. versimpeld worden tot algemenere categorieën. In een apart tabblad van de Excel sheet kunnen kolom-gewijs downstream-categorieën worden gekoppeld aan de nieuwe landgebruik categorieën. De downstream-categorieën moeten vervolgens ook genummerd worden in een Excel tabblad met gelijke naam als de kolom. In onderstaande tabel worden twee downstream categorieën toegevoegd aan de eerdere beslisregels. 

| newval | description | algemene_categorie | bostypen | 
| ------ | ------ | ------ |------ |
| 10 | Gemengd droog bos met productie | Bos | Gemengd|
| 11 | Droog Loofbos met productie | Bos | Loof | 
| 12 | Gebouw op bedrijventerrein | Bebouwing | | 
| 13 | Gebouw | Bebouwing | |

De doorvertaling van beide downstream categorieen van een categorie naar een pixelwaarde gebeurt in een aparte tabel voor elk:

|description|value|
|---|---|
|Bos|1|
|Bebouwing|2|

|description|value|
|---|---|
|Gemengd|1|
|Loof|2|

### toepassing
De MRT wordt aangestuurd via de Command Prompt. Er zijn drie vereiste parameters en diverse optionele. De vereiste parameters dienen als eerste en in de juiste volgorde ingevoerd te worden.

  1. `xls` volledig adres naar de Excel sheet met de reclass rules en optioneel `downstream` doorvertaling(en)
  2. `rast` volledig adres naar het gecombineerde raster
  3. `us` naam van het Excel tabblad waarin de reclass-rules staan

De optionele parameters zijn:

  1. `--help` laat help zien en sluit programma weer af
  2. `--ds` naam van tabblad met downstream  informatie
  3. `--test` verifieer of alle input in orde is, doet verder niks
  4. `--report` maak rapport (Excel sheet) met alle informatie  over de uitkomsten van de multi-Reclass. Rapporteert oa over bruto- en netto areaal van elke beslisregel. 
  4. `--write` schrijf de nieuwe landgebruik categorieën en/of een of meer downstream categorieën weg als een geospatial raster
  5. `--xtnt` ruimtelijke extent van het output raster. Keuze uit `BNL` (0, 300.000, 280.000, 625.000) of `LCEU` (10.000, 300.000, 280.000, 620.000). Default `BNL`.
  6. `--of` output bestandstype. Keuze uit `geotiff`, `flt` of `map`. Default `geotiff`
  7. `--verbose` `True`/`False`, geef meer feedback tijdens draaien van de tool. Default `False`.
  8. `--base_out` directory waar de output aangemaakt wordt. 

Onderstaand voorbeeld draait het MRT en creëert een rapport en een nieuw Geotiff raster met LCEU extent met daarin de nieuwe landgebruik categorieën (aangeduid als 'newval'). 

`python MRT.py c:/apps/scenario_reclass.xlsx c:/apps/combinatie_raster.tif upstream_sheet --report --write newval --xtnt LCEU --base_out c:/apps/output`



#### meer weten?
Neem contact op met [Hans Roelofsen](https://research.wur.nl/en/persons/hans-roelofsen) of [Henk Meeuwsen](https://research.wur.nl/en/persons/henk-meeuwsen)


