"""
Command line interface for the Multi Reclass Tool (MRT).
Hans Roelofsen, WEnR, 24 augustus 2020

"""

import os
import sys
import argparse
import mrt_classes as mrtc
import mrt_helpers as mrt

parser = argparse.ArgumentParser()
parser.add_argument('xls', help='path and filename of the reclass rule XLS')
parser.add_argument('rast', help='path and filename to Combined raster', type=mrt.geospatial_raster)
parser.add_argument('us', help='Upstream: sheet name with reclass rules')
parser.add_argument('--ds', help='Downstream: sheet name with downstream categories', default=None)
parser.add_argument('--test', help='Verify that all input is in order. Do nothing', action='store_true')
parser.add_argument('--report', help='Write report to file', action='store_true')
parser.add_argument('--xtab', help='Write report to file', action='store_true')
parser.add_argument('--write', help='Name of a downstream model(s) or newval to write as raster to file',
                    nargs='+')
parser.add_argument('--xtnt', help='Extent in RD for writing raster files.', choices=['BNL', 'LCEU'], default='BNL')
parser.add_argument('--of', help='Output file type.', choices=['geotiff', 'flt', 'map'], default='geotiff')
parser.add_argument('--base_out', help='Base dir for output', default=None)
parser.add_argument('--verbose', help='verbose feedback', action='store_true')
args = parser.parse_args()


# Create base instance
hans = mrtc.ReClass(xls_dir=os.path.dirname(args.xls),
                    xls_in=os.path.basename(args.xls),
                    upstream_sheet=args.us,
                    downstream_sheet=args.ds,
                    combined_raster_dir=os.path.dirname(args.rast),
                    combined_raster_in=os.path.basename(args.rast),
                    base_out=args.base_out,
                    verbose=args.verbose)

# Parse rules and calculate reclassed values
hans.look_upstream()

# Parse downstream information if needed
if args.ds:
    hans.look_downstream()

if args.test:
    hans.test()
    sys.exit(0)

if args.xtab:
    hans.cross_tab()

# Reclass input raster to one or more new rasters
if args.write:
    for rast in args.write:
        try:
            hans.write_raster(request_raster=rast, extent=args.xtnt, out_format=args.of)
        except AssertionError:
            continue

# Write report if needed
if args.report or 'newval' in args.write:
    hans.write_report()

sys.exit(0)




